@@ -1003,6 +1003,8 @@ static void bluetooth_client_init(BluetoothClient *client)
 {
 	BluetoothClientPrivate *priv = BLUETOOTH_CLIENT_GET_PRIVATE(client);
 
+	g_type_class_ref (BLUETOOTH_TYPE_STATUS);
+
 	priv->store = gtk_tree_store_new(_BLUETOOTH_NUM_COLUMNS, G_TYPE_OBJECT,
 					 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 					 G_TYPE_UINT, G_TYPE_STRING,
@@ -1125,7 +1127,7 @@ _bluetooth_client_get_discoverable (BluetoothClient *client)
  * _bluetooth_client_set_discoverable:
  * @client: a #BluetoothClient object
  * @discoverable: whether the device should be discoverable
- * @timeout: timeout in seconds for making undiscoverable, or 0 for never.
+ * @timeout: timeout in seconds for making undiscoverable, or 0 for never
  *
  * Sets the default adapter's discoverable status.
  *
@@ -1269,12 +1271,12 @@ static void bluetooth_client_finalize(GObject *client)
 
 	g_type_class_unref (g_type_class_peek (BLUETOOTH_TYPE_STATUS));
 
-	g_object_unref(priv->manager);
+	if (priv->manager)
+		g_object_unref (priv->manager);
 
 	g_object_unref(priv->store);
 
-	if (priv->default_adapter)
-		gtk_tree_row_reference_free (priv->default_adapter);
+	gtk_tree_row_reference_free (priv->default_adapter);
 
 	G_OBJECT_CLASS(bluetooth_client_parent_class)->finalize(client);
 }
@@ -1284,8 +1286,6 @@ static void bluetooth_client_class_init(BluetoothClientClass *klass)
 	GObjectClass *object_class = (GObjectClass *) klass;
 	GError *error = NULL;
 
-	g_type_class_ref (BLUETOOTH_TYPE_STATUS);
-
 	g_type_class_add_private(klass, sizeof(BluetoothClientPrivate));
 
 	object_class->finalize = bluetooth_client_finalize;
@@ -1318,7 +1318,7 @@ static void bluetooth_client_class_init(BluetoothClientClass *klass)
 /**
  * bluetooth_client_new:
  *
- * Returns a reference to the #BluetoothClient singleton. Use #g_object_unref() the object when done.
+ * Returns a reference to the #BluetoothClient singleton. Use g_object_unref() when done with the object.
  *
  * Return value: (transfer full): a #BluetoothClient object.
  **/
@@ -1733,11 +1733,10 @@ rev_sort_services (const char *servicea, const char *serviceb)
 
 /**
  * bluetooth_client_connect_service:
- *
  * @client: a #BluetoothClient
  * @device: the DBUS path on which to operate
  * @connect: Whether try to connect or disconnect from services on a device
- * @cancellable: optional #GCancellable object, %NULL to ignore.
+ * @cancellable: optional #GCancellable object, %NULL to ignore
  * @callback: (scope async): a #GAsyncReadyCallback to call when the connection is complete
  * @user_data: the data to pass to callback function
  *
@@ -1870,8 +1869,8 @@ bail:
 /**
  * bluetooth_client_connect_service_finish:
  * @client: a #BluetoothClient
- * @res: a #GAsyncResult.
- * @error: a #GError.
+ * @res: a #GAsyncResult
+ * @error: a #GError
  *
  * Finishes the connection operation, See bluetooth_client_connect_service().
  *
