@@ -178,18 +178,6 @@ static gchar *format_time(gint seconds)
 				"approximately %'d hours", hours), hours);
 }
 
-static void
-set_response_visible (GtkDialog *dialog,
-		      int response_id,
-		      gboolean visible)
-{
-	GtkWidget *widget;
-
-	widget = gtk_dialog_get_widget_for_response (dialog, response_id);
-	gtk_widget_set_no_show_all (widget, TRUE);
-	gtk_widget_set_visible (widget, visible);
-}
-
 static void response_callback(GtkWidget *dialog,
 					gint response, gpointer user_data)
 {
@@ -197,9 +185,7 @@ static void response_callback(GtkWidget *dialog,
 		setup_agent ();
 
 		/* Reset buttons */
-		set_response_visible (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE, FALSE);
-		set_response_visible (GTK_DIALOG (dialog), RESPONSE_RETRY, FALSE);
-		set_response_visible (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL, TRUE);
+		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), RESPONSE_RETRY, FALSE);
 
 		/* Reset status and progress bar */
 		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (progress),
@@ -245,11 +231,9 @@ static void create_window(void)
 	dialog = gtk_dialog_new_with_buttons(_("File Transfer"), NULL,
 				0,
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 				_("_Retry"), RESPONSE_RETRY,
 				NULL);
-	set_response_visible (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE, FALSE);
-	set_response_visible (GTK_DIALOG (dialog), RESPONSE_RETRY, FALSE);
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), RESPONSE_RETRY, FALSE);
 	gtk_window_set_type_hint(GTK_WINDOW(dialog),
 						GDK_WINDOW_TYPE_HINT_NORMAL);
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
@@ -517,7 +501,7 @@ static gboolean progress_callback(GDBusMethodInvocation *invocation,
 	time = format_time(remaining_time);
 
 	if (transfer_rate >= 3000)
-		rate = g_strdup_printf(_("%d KB/s"), transfer_rate / 1000);
+		rate = g_strdup_printf(_("%d kB/s"), transfer_rate / 1000);
 	else
 		rate = g_strdup_printf(_("%d B/s"), transfer_rate);
 
@@ -579,9 +563,7 @@ static gboolean error_callback(GDBusMethodInvocation *invocation,
 	gtk_widget_show (image_status);
 	gtk_label_set_markup(GTK_LABEL(label_status), message);
 
-	set_response_visible (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL, TRUE);
-	set_response_visible (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE, FALSE);
-	set_response_visible (GTK_DIALOG (dialog), RESPONSE_RETRY, TRUE);
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), RESPONSE_RETRY, TRUE);
 
 	g_object_unref (current_transfer);
 	current_transfer = NULL;
@@ -614,9 +596,8 @@ send_notify (GDBusProxy   *proxy,
 		gtk_label_set_markup(GTK_LABEL(label_status), message);
 		g_free (message);
 
-		set_response_visible (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL, TRUE);
-		set_response_visible (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE, FALSE);
-		set_response_visible (GTK_DIALOG (dialog), RESPONSE_RETRY, TRUE);
+		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), RESPONSE_RETRY, TRUE);
+
 		return;
 	}
 
@@ -733,9 +714,9 @@ show_select_dialog(void)
 
 static GOptionEntry options[] = {
 	{ "device", 0, 0, G_OPTION_ARG_STRING, &option_device,
-				N_("Remote device to use"), "ADDRESS" },
+				N_("Remote device to use"), N_("ADDRESS") },
 	{ "name", 0, 0, G_OPTION_ARG_STRING, &option_device_name,
-				N_("Remote device's name"), NULL },
+				N_("Remote device's name"), N_("NAME") },
 	{ "dest", 0, G_OPTION_FLAG_HIDDEN,
 			G_OPTION_ARG_STRING, &option_device, NULL, NULL },
 	{ G_OPTION_REMAINING, 0, 0,
@@ -754,7 +735,7 @@ int main(int argc, char *argv[])
 
 	error = NULL;
 
-	if (gtk_init_with_args(&argc, &argv, "[FILE...]",
+	if (gtk_init_with_args(&argc, &argv, _("[FILE...]"),
 				options, GETTEXT_PACKAGE, &error) == FALSE) {
 		if (error != NULL) {
 			g_printerr("%s\n", error->message);
@@ -821,7 +802,7 @@ int main(int argc, char *argv[])
 							error->message);
 			g_error_free(error);
 		} else
-			g_print("An unknown error occured\n");
+			g_print("An unknown error occurred\n");
 
 		return 1;
 	}
