@@ -494,7 +494,7 @@ void prepare_callback (GtkWidget *assistant,
 			      NULL);
 
 		/* Do we pair, or don't we? */
-		if (g_strcmp0 (user_pincode, "NULL") == 0)
+		if (automatic_pincode && pincode == NULL)
 			path = NULL;
 
 		g_object_ref(agent);
@@ -526,6 +526,8 @@ void prepare_callback (GtkWidget *assistant,
 				help = g_strdup (_("Please move the joystick of your iCade in the following directions:"));
 				pincode = get_icade_pincode (&pincode_display);
 				break;
+			default:
+				g_assert_not_reached ();
 			}
 
 			if (pincode == NULL)
